import { ICreateError, ICreateResponse, IResponse, IModelError } from './types';
/**
 * @function createError
 *
 * Creates an error response following the RFC 7807 pattern.
 *
 * @param code - HTTP status code 4xx to 5xx
 * @param type - URL for a document describing the error condition
 * @param detail - Legible error description
 * @param instance - URI exclusive for or specific error
 * @param title - Short and descriptive information
 */
export declare const createError: ({ code, title, type, detail, instance, }: ICreateError) => never;
/**
 * @function createResponse
 *
 * Simple model for successful responses.
 *
 * @param response - HTTP Response Object
 * @param payload.code - HTTP status code 1xx to 3xx
 * @param payload.message - Legible action response
 * @param payload.data - Back Data
 * @param payload.title - Short and descriptive information
 */
export declare const createResponse: (response: IResponse, { code, message, data, title }: ICreateResponse) => IResponse;
/**
 * @function handlerError
 *
 * Error handler
 *
 * @param response - Response object instance
 * @param error - Error object instance
 */
export declare const handlerError: (response: IResponse, error: IModelError) => IResponse;
//# sourceMappingURL=builder.d.ts.map